function interpol_map, map, dimx=dimx, dimy=dimy, wmask=wmask


;;; interpolates a sparsely populated scan map (designed to work only on scan maps
;;; oriented with their x axis in the direction of one of the scans)

;;;;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

;;; copyright 2007-2011 H\'el\`ene Roussel
;;; roussel@iap.fr
;;; Institut d'Astrophysique de Paris - Universit\'e Pierre et Marie Curie, France

;;; download and documentation: http://www2.iap.fr/users/roussel/herschel/

;;; Scanamorphos is distributed under the terms of the GNU General Public License
;;; (http://www.gnu.org/licenses/gpl.html).

;;; introduced December 2011: version 15

;;;;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



map_interp = map

;;; controlled interpolation in x coordinate:

ind_0 = lindgen(dimx)
ind_start = [ind_0, dimx + reverse(ind_0)]
ind = ind_start
for y = 2L, dimy - 2L, 2L do ind = [ind, y * dimx + ind_start]
if ((dimy - 1L) mod 2) eq 0 then ind = [ind, (dimy - 1L) * dimx + ind_0]

map_no_int = map(ind)
wdef = where(finite(map_no_int) gt 0, cdef)
diff_wdef = wdef(1:cdef-1) - wdef(0:cdef-2)
w = where(diff_wdef gt 2)
m_diff = median(diff_wdef(w))
w = where(diff_wdef ge 1.5 * m_diff, cw)
for k = 0L, cw - 1L do map_no_int(wdef(w(k)):wdef(w(k)+1)) = 1.
wz = where(finite(map_no_int) lt 1)

map_interp(ind(wz)) = interpol(map(ind(wdef)), float(wdef), float(wz))


mask_interp_x = intarr(dimx, dimy)
for y = 0L, dimy - 1L do begin
   w = where(finite(map(*, y)) gt 0, cw)
   if cw ge dimx / 4 then mask_interp_x(min(w):max(w), y) = 1
endfor

w = where(mask_interp_x lt 1)
map_interp(w) = !values.f_nan


mask_interp = mask_interp_x
for x = 0L, dimx - 1L do begin
   w = where(finite(map(x, *)) gt 0, cw)
   if cw ge 10 then mask_interp(x, min(w):max(w)) = 1
endfor



;;; interpolation in y coordinate:

ind_0 = dimx * lindgen(dimy)
ind_start = [ind_0, 1L + reverse(ind_0)]
ind = ind_start
for x = 2L, dimx - 2L, 2L do ind = [ind, x + ind_start]
if ((dimx - 1L) mod 2) eq 0 then ind = [ind, (dimx - 1L) + ind_0]

wdef = where(finite(map_interp(ind)) gt 0, complement=wz)
map_interp(ind(wz)) = interpol(map_interp(ind(wdef)), float(wdef), float(wz))

w = where(mask_interp lt 1)
map_interp(w) = !values.f_nan

if keyword_set(wmask) then map_interp(wmask) = !values.f_nan


return, map_interp

end

